@@ -1,6 +1,6 @@
 package DBIx::Lite;
 {
-  $DBIx::Lite::VERSION = '0.15';
+  $DBIx::Lite::VERSION = '0.16';
 }
 # ABSTRACT: Chained and minimal ORM
 use strict;
@@ -126,6 +126,8 @@ sub _autopk {
         return $self->dbh_do(sub { +($_->selectrow_array('SELECT LAST_INSERT_ID()'))[0] });
     } elsif ($driver_name eq 'SQLite') {
         return $self->dbh_do(sub { +($_->selectrow_array('SELECT LAST_INSERT_ROWID()'))[0] });
+    } elsif ($driver_name eq 'Pg') {
+        return $self->dbh_do(sub { $_->last_insert_id( undef, undef, $table_name, undef ) });
     } else {
         croak "Autoincrementing ID is not supported on $driver_name";
     }
@@ -143,7 +145,7 @@ DBIx::Lite - Chained and minimal ORM
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -311,7 +313,7 @@ Alessandro Ranellucci <aar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Alessandro Ranellucci.
+This software is copyright (c) 2014 by Alessandro Ranellucci.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
